%global module  anfft

Summary:        ANFFT is an FFT package for Python, based on FFTW
Name:           python-%{module}
Version:        0.2
Release:        13%{?dist}
Source0:        http://anfft.googlecode.com/files/%{module}-%{version}.tar.gz
License:        GPLv3+
URL:            http://anfft.googlecode.com/

BuildRequires:  python2-numpy
BuildRequires:  fftw-libs
BuildRequires:  python2-devel
BuildArch:      noarch


%global _description\
ANFFT is intended to be used in situations where large numbers\
of expensive FFTs must be performed, and for which the speed\
of the built-in NumPy or SciPy functions has been found insufficient.\
\
By default, ANFFT provides immediate results by using FFTW's\
"estimate" mode, which does not require tuning and is still very fast.\
However, each high-level function provides a keyword named "measure"\
which will invoke the full FFTW planning machinery.\
FFTW will investigate which implementations are fastest on your\
hardware for the given problem size, and ANFFT will transparently\
cache this information to speed up later transforms on arrays of\
the same size and type. Accumulated FFTW "wisdom" about which\
methods work best is stored across Python sessions in a configuration\
file in ~/.anfft

%description %_description

%package -n python2-%{module}
Summary: %summary
Requires:       python2-numpy
Requires:       fftw-libs
%{?python_provide:%python_provide python2-%{module}}

%description -n python2-%{module} %_description

%prep
%setup -q -n %{module}-%{version}

%build
%__python2 setup.py build

%check
libdir=build/lib
export PYTHONPATH=`pwd`/build/$libdir
%__python2 -c 'import anfft; anfft.test()'

%install
%py2_install

%files -n python2-%{module}
%license COPYING.txt
%doc README.txt
%{python2_sitelib}/anfft/
%{python2_sitelib}/anfft-%{version}-py*.egg-info

%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Aug 19 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 0.2-11
- Python 2 binary package renamed to python2-anfft
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-8
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Jul 11 2012  Thibault North <tnorth@fedoraproject.org> - 0.2-1
- Update to 0.2

* Tue May 1 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.1-4
- Fix requires, triggered by changes in fftw packaging.

* Thu Feb 2 2012 Thibault North <tnorth@fedoraproject.org> - 0.1-3
- Fix requires again (thanks oget)

* Mon Jan 30 2012 Thibault North <tnorth@fedoraproject.org> - 0.1-2
- Various fixes (requires, cleaning)

* Sun Jan 8 2012  Thibault North <tnorth@fedoraproject.org> - 0.1-1
- Initial import
